@@ -173,6 +173,10 @@ typedef struct nv_ioctl_free_os_event
     (((domain) == NV_CTL_DEVICE_PCI_DOMAIN) && \
      ((bus) == NV_CTL_DEVICE_PCI_BUS) && ((slot) == NV_CTL_DEVICE_PCI_SLOT))
 
+#define NV_PCI_DEV_FMT          "%04x:%02x:%02x.%x"
+#define NV_PCI_DEV_FMT_ARGS(nv) (nv)->pci_info.domain, (nv)->pci_info.bus, \
+                                (nv)->pci_info.slot, (nv)->pci_info.function
+
 /* status code */
 typedef struct nv_ioctl_status_code
 {
@@ -223,7 +227,7 @@ typedef union
 #define NVRM_PCICFG_BAR_MEMTYPE_64BIT   0x00000004
 #define NVRM_PCICFG_BAR_ADDR_MASK       0xfffffff0
 
-#define NVRM_PCICFG_NUM_DWORDS          64
+#define NVRM_PCICFG_NUM_DWORDS          16
 
 #define NV_GPU_NUM_BARS                 3
 #define NV_GPU_BAR_INDEX_REGS           0
@@ -331,7 +335,7 @@ typedef struct
 
     NvU32  interrupt_line;
 
-    NvU32 primary_vga;
+    NvBool primary_vga;
 
     NvU32 sim_env;
 
@@ -610,6 +614,8 @@ RM_STATUS  NV_API_CALL  nv_nvmap_release_pages   (nv_state_t *, NvU64, NvU64 *,
 #endif
 RM_STATUS  NV_API_CALL  nv_alloc_os_descriptor_handle (nv_state_t *, NvS32, void *, NvU64, NvU32 *);
 NvU64      NV_API_CALL  nv_get_dma_start_address (nv_state_t *);
+void       NV_API_CALL  nv_pci_trigger_recovery  (nv_state_t *);
+RM_STATUS  NV_API_CALL  nv_set_primary_vga_status(nv_state_t *);
 
 #if defined(NVCPU_X86) || defined(NVCPU_X86_64)
 NvBool     NV_API_CALL  nv_is_virtualized_system  (nv_stack_t *);
@@ -686,6 +692,7 @@ RM_STATUS  NV_API_CALL  rm_p2p_destroy_mapping    (nv_stack_t *, NvU64);
 RM_STATUS  NV_API_CALL  rm_p2p_get_pages          (nv_stack_t *, NvU64, NvU32, NvU64, NvU64, NvU64 **, NvU32 **, NvU32 **, NvU32 *, void *, void (*)(void *), void *);
 RM_STATUS  NV_API_CALL  rm_p2p_put_pages          (nv_stack_t *, NvU64, NvU32, NvU64, void *);
 RM_STATUS  NV_API_CALL  rm_get_cpu_type           (nv_stack_t *, nv_cpu_type_t *);
+RM_STATUS  NV_API_CALL  rm_get_gpu_debug_data     (nv_stack_t *, nv_state_t *, void *, NvU32 *);
 
 RM_STATUS  NV_API_CALL  rm_gpu_ops_create_session (nv_stack_t *, nvgpuSessionHandle_t *);
 RM_STATUS  NV_API_CALL  rm_gpu_ops_destroy_session (nv_stack_t *, nvgpuSessionHandle_t);
